from dexhub.abi.klay_abi import AbiClaySwap,AbiSd,AbiSynapseKlay
from dexhub.abi.dfk_abi import AbiCv,AbiSynapse
from dexhub.abi.eth_abi import AbiUniswapV3
from dexhub.abi.avax_abi import AbiJoe,AbiPangolin
from dexhub.abi.arbitrum_abi import AbiArbitrumJoe,AbiArbitrumSushi



from web3 import Web3

class SD:
    #dex
    sd_route=Web3.to_checksum_address('0x9e987E5E9aB872598f601BE4aCC5ac23F484845E')
    sd_factory=Web3.to_checksum_address('0x36fAE766e51f17F8218C735f58426E293498Db2B')

class AddressSD:
    #dex
    sd_route=Web3.to_checksum_address('0x9e987E5E9aB872598f601BE4aCC5ac23F484845E')
    sd_factory=Web3.to_checksum_address('0x36fAE766e51f17F8218C735f58426E293498Db2B')

class AddressKlaySwap:
    ks_route=Web3.to_checksum_address('0x6C14E2e4bae412137437A8Ec9e57263212d141A0')
    ks_factory=Web3.to_checksum_address('0xA15Be7e90df29A4aeaD0C7Fc86f7a9fBe6502Ac9')

class AddressSynapseKlay:
    sd_l1_bridge_zap=Web3.to_checksum_address('8671A0465844a15eb7230C5dd8d6032c26c655B7')
    
class AddressClaySwap:
    clay_swap_route=Web3.to_checksum_address('0xEf71750C100f7918d6Ded239Ff1CF09E81dEA92D')
    clay_swap_factory=Web3.to_checksum_address('0x3679c3766E70133Ee4A7eb76031E49d3d1f2B50c')

class KlayToken:
    #erc20
    ousdt=Web3.to_checksum_address('0xceE8FAF64bB97a73bb51E115Aa89C17FfA8dD167')
    oeth=Web3.to_checksum_address('0x34d21b1e550D73cee41151c77F3c73359527a396')
    owbtc=Web3.to_checksum_address('0x16D0e1fBD024c600Ca0380A4C5D57Ee7a2eCBf9c')
    jewel=Web3.to_checksum_address('0x30C103f8f5A3A732DFe2dCE1Cc9446f545527b43')
    gold=Web3.to_checksum_address('0xe7a1B580942148451E47b92e95aEB8d31B0acA37')
    tear=Web3.to_checksum_address('0x8Be0cbA3c8c8F392408364ef21dfCF714A918234')
    wavax=Web3.to_checksum_address('0xCd8fE44A29Db9159dB36f96570d7A4d91986f528')
    wklay=Web3.to_checksum_address('0x19Aac5f612f524B754CA7e7c41cbFa2E981A4432')
    jade=Web3.to_checksum_address('0xB3F5867E277798b50ba7A71C0b24FDcA03045eDF')
    claim=Web3.to_checksum_address('0xbA9725eaCCF07044625F1D232eF682216F5371c2')
    ousdc=Web3.to_checksum_address('0x754288077D0fF82AF7a5317C7CB8c444D421d103')
    kdai=Web3.to_checksum_address('0x5c74070FDeA071359b86082bd9f9b3dEaafbe32b')
    oxpr=Web3.to_checksum_address('0x9eaeFb09fe4aABFbE6b1ca316a3c36aFC83A393F')



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="dexhub",
    version="0.7.9",
    author="elmtlab",
    author_email="elmtlab@outlook.com",
    description="dex connector",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/elmtlab/aurum",
    packages=setuptools.find_packages(),
    install_requires=[
        'web3'
    ],
    license_files="LICENSE",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)


from web3 import Web3

class AddressArbitrumJoe:
    #dex
    joe_v2_factory_address=Web3.to_checksum_address('0x1886D09C9Ade0c5DB822D85D21678Db67B6c2982')
    joe_v2_route_address=Web3.to_checksum_address('0x7BFd7192E76D950832c77BB412aaE841049D8D9B')
    joe_v2_quote_address=Web3.to_checksum_address('0x7f281f22eDB332807A039073a7F34A4A215bE89e')

    joe_v1_route_address=Web3.to_checksum_address('0xbeE5c10Cf6E4F68f831E11C1D9E59B43560B3642')
    joe_v1_factory_address=Web3.to_checksum_address('0xaE4EC9901c3076D0DdBe76A520F9E90a6227aCB7')

class AddressAbitrumSushi:
    sushi_factory_address=Web3.to_checksum_address('0xc35DADB65012eC5796536bD9864eD8773aBc74C4')
    sushi_route_address=Web3.to_checksum_address('0x1b02dA8Cb0d097eB8D57A175b88c7D8b47997506')

class AddressArbitrumTokens:
    #erc20
    usdc=Web3.to_checksum_address('0xFF970A61A04b1cA14834A43f5dE4533eBDDB5CC8')
    daie=Web3.to_checksum_address('0xDA10009cBd5D07dd0CeCc66161FC93D7c9000da1')
    weth=Web3.to_checksum_address('0x82aF49447D8a07e3bd95BD0d56f35241523fBab1')
    wbtc=Web3.to_checksum_address('0x2f2a2543B76A4166549F7aaB2e75Bef0aefC5B0f')
    joe=Web3.to_checksum_address('0x371c7ec6D8039ff7933a2AA28EB827Ffe1F52f07')
    gmx=Web3.to_checksum_address('0xfc5A1A6EB076a2C7aD06eD22C90d7E710E35ad0a')
    arb=Web3.to_checksum_address('0x912CE59144191C1204E64559FE8253a0e49E6548')



from web3 import Web3

class AddressJoe:
    #dex v2.1
    joe_quote_address=Web3.to_checksum_address('0x9Dbf1706577636941Ab5f443D2AEbE251ccd1648')
    joe_route_address=Web3.to_checksum_address('0xE3Ffc583dC176575eEA7FD9dF2A7c65F7E23f4C3')
    joe_factory_address=Web3.to_checksum_address('0x6E77932A92582f504FF6c4BdbCef7Da6c198aEEf')
    #dex
    joe_v2_factory_address=Web3.to_checksum_address('0x6E77932A92582f504FF6c4BdbCef7Da6c198aEEf')
    joe_v2_route_address=Web3.to_checksum_address('0xE3Ffc583dC176575eEA7FD9dF2A7c65F7E23f4C3')
    joe_v2_quote_address=Web3.to_checksum_address('0x9Dbf1706577636941Ab5f443D2AEbE251ccd1648')

    joe_v1_factory_address=Web3.to_checksum_address('0x9Ad6C38BE94206cA50bb0d90783181662f0Cfa10')
    joe_v1_route_address=Web3.to_checksum_address('0x60aE616a2155Ee3d9A68541Ba4544862310933d4')

class AddressPangolin:
    pan_factory_address=Web3.to_checksum_address('0xefa94DE7a4656D787667C749f7E1223D71E9FD88')
    pan_route_address=Web3.to_checksum_address('0xE54Ca86531e17Ef3616d22Ca28b0D458b6C89106')

class AddressAvaxTokens:
    #erc20
    wavax=Web3.to_checksum_address('0xB31f66AA3C1e785363F0875A1B74E27b85FD66c7')
    usdc=Web3.to_checksum_address('0xB97EF9Ef8734C71904D8002F8b6Bc66Dd9c48a6E')
    daie=Web3.to_checksum_address('0xd586E7F844cEa2F87f50152665BCbc2C279D8d70')
    usdt=Web3.to_checksum_address('0x9702230A8Ea53601f5cD2dc00fDBc13d4dF4A8c7')
    ethe=Web3.to_checksum_address('0x49D5c2BdFfac6CE2BFdB6640F4F80f226bc10bAB')
    btce=Web3.to_checksum_address('0x50b7545627a5162F82A992c33b87aDc75187B218')
    btcb=Web3.to_checksum_address('0x152b9d0FdC40C096757F570A51E494bd4b943E50')
    joe=Web3.to_checksum_address('0x6e84a6216eA6dACC71eE8E6b0a5B7322EEbC0fDd')
    gmx=Web3.to_checksum_address('0x62edc0692BD897D2295872a9FFCac5425011c661')



